#-------------------------------------------------------------------------------
# 此工程是titanframework下所有工程文件共用的部分，主要包含系统判定，编译目录设置等
#
# Author: Tony Guo
#-------------------------------------------------------------------------------

### 默认的编译目标目录 ###
isEmpty(DIST_DIR){
    DIST_DIR = $${ROOT_DIR}/dist
}

DEFINES += APP_VERSION=\\\"$${VERSION}\\\"
### 为了防止在windows下编译出的dll带版本数字的问题 ###
win32:VERSION=

DEFINES += QT_NO_FOREACH

win32-msvc* {
    ### Window XP支持 ###
    QMAKE_LFLAGS_WINDOWS = /SUBSYSTEM:WINDOWS,5.01
    ### generating pdb in release mode ###
    QMAKE_CXXFLAGS_RELEASE += /Zi
    QMAKE_LFLAGS_RELEASE += /DEBUG
}

### 获取系统平台名称(platform) ###
TANCC=$$section(QMAKESPEC, /, -3, -3)
TANOS=$$(TANPM_OSNAME)
isEmpty(TANOS){
    TANOS=unknowos
    win32 {
       TANOS=windows
    }
    linux {
        TANOS=linux
    }
    macx {
       TANOS=macx
    }
}
TANPLATFORM=$${TANOS}-$${TANCC}-qt$$[QT_VERSION]

### 定义DIST_PLATFORM ###
DIST_PLATFORM=$${DIST_DIR}/$${TANPLATFORM}

DEFINES += APP_PLATFORM=\\\"$${TANPLATFORM}\\\"


### C++11支持 ###
CONFIG += c++11

### 设置DEBUG模式后缀 ###
CONFIG += debug_and_release
CONFIG(debug, debug | release) {
    win32 {
        DEBUG_SUFFIX = d
    }
    macx {
        DEBUG_SUFFIX = _debug
    }
} else {
    DEBUG_SUFFIX =
}

### 设置编译目标目录 ###
DIST_BIN = $$system_path($${DIST_PLATFORM}/bin)
DIST_LIB = $$system_path($${DIST_PLATFORM}/lib)
DIST_STATICLIB = $$system_path($${DIST_PLATFORM}/static)

DESTDIR = $${DIST_BIN}
equals(TEMPLATE, "lib") {
    CONFIG(staticlib) {
        CONFIG(debug, debug | release) {
            DESTDIR = $${DIST_STATICLIB}/debug
        } else {
            DESTDIR = $${DIST_STATICLIB}/release
        }
    }
    else {
        CONFIG(debug, debug | release) {
            DESTDIR = $${DIST_LIB}/debug
        } else {
            DESTDIR = $${DIST_LIB}/release
        }
    }
}

### 定义TOPSIN_SDK头文件目录 ###
INCLUDEPATH += $${DIST_PLATFORM}/include

### 编译link设置 ###
for (lib, DLL_LIBS) {
    tanpmlibpath = $${DIST_PLATFORM}/tanpm/$${lib}
    exists($${tanpmlibpath}) {
        INCLUDEPATH += $${tanpmlibpath}/include
        CONFIG(debug, debug | release) {
            exists($${tanpmlibpath}/lib/debug) {
                LIBS += -L$${tanpmlibpath}/lib/debug -l$${lib}$${DEBUG_SUFFIX}
            } else {
                LIBS += -L$${tanpmlibpath}/lib/release -l$${lib}
            }
        } else {
            LIBS += -L$${tanpmlibpath}/lib/release -l$${lib}
        }
    }
    else {
        CONFIG(debug, debug | release) {
            exists($${DIST_LIB}/debug) {
                LIBS += -L$${DIST_LIB}/debug -l$${lib}$${DEBUG_SUFFIX}
            } else {
                LIBS += -L$${DIST_LIB}/release -l$${lib}
            }
        } else {
            LIBS += -L$${DIST_LIB}/release -l$${lib}
        }
    }
}

for (lib, STATIC_LIBS) {
    tanpmlibpath = $${DIST_PLATFORM}/tanpm/$${lib}
    exists($${tanpmlibpath}) {
        INCLUDEPATH += $${tanpmlibpath}/include
        exists($${tanpmlibpath}/static) {
            DEFINES += $$upper($${lib})_STATIC
            CONFIG(debug, debug | release) {
                exists($${tanpmlibpath}/static/debug) {
                    LIBS += -L$${tanpmlibpath}/static/debug -l$${lib}$${DEBUG_SUFFIX}
                } else {
                    LIBS += -L$${tanpmlibpath}/static/release -l$${lib}
                }
            } else {
                LIBS += -L$${tanpmlibpath}/static/release -l$${lib}
            }
        }
    }
    else {
        CONFIG(debug, debug | release) {
            exists($${DIST_STATICLIB}/debug) {
                LIBS += -L$${DIST_STATICLIB}/debug -l$${lib}$${DEBUG_SUFFIX}
            } else {
                LIBS += -L$${DIST_STATICLIB}/release -l$${lib}
            }
        } else {
            LIBS += -L$${DIST_STATICLIB}/release -l$${lib}
        }
    }
}

### 导出头文件 ###
equals(TEMPLATE, "lib") {
    ### 查看SDK头文件目标路径是否存在，不存在则创建 ###
    DIST_HEADER = $$system_path($${DIST_PLATFORM}/include/$${HEADER_DIR})
    !exists($${DIST_HEADER}) {
        mkpath($${DIST_HEADER})
    }

    ### 导出header ###
    win32 {
        system(copy $$system_path($${SRC_PWD}/*.h) $${DIST_HEADER})
    } else {
        system(cp $$system_path($${SRC_PWD}/*.h) $${DIST_HEADER})
    }
}

### 复制语言包.qm ###
!isEmpty(QM_LIST) {
    DIST_LANGUAGE = $$system_path($${DIST_PLATFORM}/lang)
    !exists($${DIST_LANGUAGE}) {
        mkpath($${DIST_LANGUAGE})
    }
    for(qm, QM_LIST) {
        win32{
            system(copy $$system_path($${qm}) $${DIST_LANGUAGE})
        }
        else{
            system(cp $$system_path($${qm}) $${DIST_LANGUAGE})
        }
    }
}



### 设置Macx rpath ###
macx {
  QMAKE_LFLAGS += -Wl,-rpath,@loader_path,-rpath,@executable_path
  QMAKE_LFLAGS += -Wl,-rpath,@executable_path/../lib
  QMAKE_SONAME_PREFIX = @rpath
}

### 设置Linux rpath ###
linux {
  QMAKE_RPATHDIR += .
  QMAKE_RPATHDIR += ../lib
}

#################################  COPYRIGHT ###################################
#                                                                              #
#     Copyright (c) 2009-2020 TopLinker Co.,Ltd. (http://www.toplinker.net)    #
#                            ALL RIGHTS RESERVED                               #
#                                                                              #
#     The entire contents of this file is protected by copyright law and       #
#     international treaties. Unauthorized reproduction, reverse-engineering   #
#     and distribution of all or any portion of the code contained in this     #
#     file is strictly prohibited and may result in severe civil and           #
#     criminal penalties and will be prosecuted to the maximum extent          #
#     possible under the law.                                                  #
#                                                                              #
#     RESTRICTIONS                                                             #
#                                                                              #
#     THE SOURCE CODE CONTAINED WITHIN THIS FILE AND ALL RELATED               #
#     FILES OR ANY PORTION OF ITS CONTENTS SHALL AT NO TIME BE                 #
#     COPIED, TRANSFERRED, SOLD, DISTRIBUTED, OR OTHERWISE MADE                #
#     AVAILABLE TO OTHER INDIVIDUALS WITHOUT WRITTEN CONSENT                   #
#     AND PERMISSION FROM DEVELOPER MACHINES                                   #
#                                                                              #
#     CONSULT THE END USER LICENSE AGREEMENT FOR INFORMATION ON                #
#     ADDITIONAL RESTRICTIONS.                                                 #
#                                                                              #
################################################################################
